# encoding: utf-8
'''
This module contains the meta-data of the package.
'''

__author__ = 'David Kundih'
__copyright__ = 'Copyright © 2021- David Kundih'
__credits__ = [
	'dkundih <https://github.com/dkundih>'

]
__license__ = 'Apache 2.0 License'
__version__ = '1.0.1+'